Welcome to the Pylira Documentation
===================================

Pylira is a Python package for Bayesian low-counts image reconstruction and analysis.

.. toctree::
  :maxdepth: 2

  pylira/index.rst
  pylira/user/index.rst
  pylira/api/index.rst
  pylira/developer.rst
  pylira/references.rst
  pylira/changelog.rst
